@@ -1,16 +1,15 @@
 import unittest
 
 from itemloaders import ItemLoader
-from itemloaders.processors import Identity, Compose, TakeFirst
+from itemloaders.processors import Compose, Identity, TakeFirst
 
 
 class TestOutputProcessorDict(unittest.TestCase):
     def test_output_processor(self):
-
         class TempDict(dict):
             def __init__(self, *args, **kwargs):
                 super(TempDict, self).__init__(self, *args, **kwargs)
-                self.setdefault('temp', 0.3)
+                self.setdefault("temp", 0.3)
 
         class TempLoader(ItemLoader):
             default_item_class = TempDict
@@ -20,7 +19,7 @@ class TestOutputProcessorDict(unittest.TestCase):
         loader = TempLoader()
         item = loader.load_item()
         self.assertIsInstance(item, TempDict)
-        self.assertEqual(dict(item), {'temp': 0.3})
+        self.assertEqual(dict(item), {"temp": 0.3})
 
 
 class TestOutputProcessorItem(unittest.TestCase):
@@ -29,9 +28,9 @@ class TestOutputProcessorItem(unittest.TestCase):
             default_input_processor = Identity()
             default_output_processor = Compose(TakeFirst())
 
-        item = dict()
-        item.setdefault('temp', 0.3)
+        item = {}
+        item.setdefault("temp", 0.3)
         loader = TempLoader(item=item)
         item = loader.load_item()
         self.assertIsInstance(item, dict)
-        self.assertEqual(dict(item), {'temp': 0.3})
+        self.assertEqual(dict(item), {"temp": 0.3})
